pilas.ejemplos.cargador

Package pilas :: Package ejemplos :: Module cargador |
[hide private]
[frames] | no frames]

# Module cargador

source code

Classes | [hide private]
| VentanaEjemplos

Functions | [hide private]
main(parent=None) | source code

Variables | [hide private]
| MENSAJE_PRESENTACION = `u"""Bienvenido al cargador de ejempl`...``

Variables Details | [hide private]

  ### MENSAJE_PRESENTACION Value:
      u"""Bienvenido al cargador de ejemplos.

      Selecciona un ejemplo usando el panel de
      la izquierda y luego verás el código acá.
      """